%define srcname pykickstart

Name:		python-kickstart
Version:	2.25
Release:	%mkrel 1
Summary:	Python library and tools for manipulating kickstart files
License:	GPLv2 and MIT
Group:		Development/Python
# This is a Red Hat maintained package. Thus the source is only available from
# within the srpm:
# http://dl.fedoraproject.org/pub/fedora/linux/development/rawhide/source/SRPMS/p/
# or git git://git.fedorahosted.org/git/pykickstart.git
Source0:	%{srcname}-%{version}.tar.gz

# Patches from Fedora
Patch0:		0001-Support-file-URLs-for-ostree-1327460.patch
Patch1:		0002-Add-support-for-excludeWeakdeps.patch
Patch2:		0003-Add-documentation-for-excludeWeakdeps.patch
Patch3:		0004-Ignore-DeprecationWarnings.patch
Patch10:	update-potfile.patch

Url:		http://fedoraproject.org/wiki/pykickstart
BuildArch:	noarch
BuildRequires:	gettext
BuildRequires:	python-devel
BuildRequires:	python-nose
BuildRequires:	python-setuptools
BuildRequires:	python-requests
BuildRequires:	python-six
BuildRequires:	python-coverage

BuildRequires:	transifex-client

BuildRequires:	python3-devel
BuildRequires:	python3-nose
BuildRequires:	python3-setuptools
BuildRequires:	python3-requests
BuildRequires:	python3-six
BuildRequires:	python3-coverage
BuildRequires:	python3-mypy

%description
Python library and tools for manipulating kickstart files

# Pykickstart utilities
%package utils
Summary:	Python utilities for manipulating kickstart files
Group:		Development/Python
Requires:	python3-kickstart = %{version}-%{release}

%description utils
Python utilities for manipulating kickstart files.

# Python 2 library
%package -n python2-kickstart
Summary:	Python 2 library for manipulating kickstart files
Group:		Development/Python
Obsoletes:	python-kickstart < %{version}-%{release}
Provides:	python-kickstart = %{version}-%{release}
Requires: 	python-six
Requires: 	python-requests

%description -n python2-kickstart
Python 2 library for manipulating kickstart files.
The binaries are found in the python-kickstart-utils package.

# Python 3 library
%package -n python3-kickstart
Summary:	Python 3 library for manipulating kickstart files
Group:		Development/Python
Requires: 	python3-six
Requires: 	python3-requests

%description -n python3-kickstart
Python 3 library for manipulating kickstart files.
The binaries are found in the python-kickstart-utils package.

%prep
%autosetup -n %{srcname}-%{version} -p1

%build
cp -a . %{py3dir}

# Build Python 2 version
PYTHON=%{__python2} %make_build

# Build Python 3 version
pushd %{py3dir}
PYTHON=%{__python3} %make_build
popd


%install
# Install Python 2 version
PYTHON=%{__python2} %make_install

# Install Python 3 version
pushd %{py3dir}
PYTHON=%{__python3} %make_install
popd

%check
# Test Python 2 version
PYTHON=%{__python2} make test

# Test Python 3 version
pushd %{py3dir}
PYTHON=%{__python3} make test
popd

%files utils
%license COPYING
%doc README
%doc docs/kickstart-docs.rst
%{_bindir}/ksvalidator
%{_bindir}/ksflatten
%{_bindir}/ksverdiff
%{_bindir}/ksshell
%{_mandir}/man1/*

%files -n python2-kickstart
%doc docs/programmers-guide
%doc docs/kickstart-docs.rst
%{python2_sitelib}/pykickstart*egg*
%{python2_sitelib}/pykickstart/*py*
%{python2_sitelib}/pykickstart/commands/*py*
%{python2_sitelib}/pykickstart/handlers/*py*
%{python2_sitelib}/pykickstart/locale/

%files -n python3-kickstart
%doc docs/programmers-guide
%doc docs/kickstart-docs.rst
%{python3_sitelib}/pykickstart*egg*
%{python3_sitelib}/pykickstart/*py*
%{python3_sitelib}/pykickstart/commands/*py*
%{python3_sitelib}/pykickstart/handlers/*py*
%{python3_sitelib}/pykickstart/locale/


%changelog
* Sun Nov 27 2016 ngompa <ngompa> 2.25-1.mga6
+ Revision: 1070454
- Update to 2.25
- Add patches from Fedora

* Wed Jan 13 2016 ngompa <ngompa> 2.24-1.mga6
+ Revision: 922387
- Add missing python3-mypy BR
- Add python(3)-coverage as BuildRequires
- Update to 2.24

* Sun Nov 15 2015 ngompa <ngompa> 2.20-1.mga6
+ Revision: 903327
- Upgrade to 2.20

* Wed Oct 15 2014 umeabot <umeabot> 1.77-8.mga5
+ Revision: 745860
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.77-7.mga5
+ Revision: 728942
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.77-6.mga5
+ Revision: 688111
- Mageia 5 Mass Rebuild

  + pterjan <pterjan>
    - Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 1.77-4.mga4
+ Revision: 543757
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.77-3.mga4
+ Revision: 498829
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Jan 13 2013 umeabot <umeabot> 1.77-2.mga3
+ Revision: 379038
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 04 2011 anaselli <anaselli> 1.77-1.mga2
+ Revision: 175971
- imported package python-kickstart

